doapfiend.utils.DoapPrinter

Package doapfiend :: Module utils :: Class DoapPrinter |
[hide private]
[frames] | no frames]

# Class DoapPrinter

source code

    object --+
             |
            DoapPrinter

Prints DOAP in human readable text

Instance Methods | [hide private]
__init__(self, doap, brief=False) Initialize attributes | source code
None |
print_doap(self) Print DOAP in human readable text, optionally colorized | source code
print_misc(self) Prints basic DOAP metadata | source code
print_repos(self) Prints DOAP repository metadata | source code
print_releases(self) Print DOAP package release metadata | source code
print_people(self) Print maintainers, documenters, helpers etc. | source code
None |
print_field(self, field) Print a DOAP element | source code
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, doap, brief=False) (Constructor) | source code
Initialize attributes Overrides: object.__init__

### print_doap(self) | source code
Print DOAP in human readable text, optionally colorized Returns: None Just prints DOAP

### print_field(self, field) | source code
Print a DOAP element Parameters: `field` (string) - A misc DOAP element Returns: None Nothing